@@ -19,10 +19,8 @@ else:
             signal.alarm(math.ceil(seconds))
         arm_alarm = alarm_signal
 
-from eventlet import patcher
 from eventlet.hubs import timer, IOClosed
-from eventlet.support import greenlets as greenlet, clear_sys_exc_info
-time = patcher.original('time')
+from eventlet.support import greenlets as greenlet, clear_sys_exc_info, monotonic, six
 
 g_prevent_multiple_readers = True
 
@@ -113,12 +111,15 @@ class BaseHub(object):
     READ = READ
     WRITE = WRITE
 
-    def __init__(self, clock=time.time):
+    def __init__(self, clock=None):
         self.listeners = {READ: {}, WRITE: {}}
         self.secondaries = {READ: {}, WRITE: {}}
         self.closed = []
 
+        if clock is None:
+            clock = monotonic.monotonic
         self.clock = clock
+
         self.greenlet = greenlet.greenlet(self.run)
         self.stopping = False
         self.running = False
@@ -187,7 +188,7 @@ class BaseHub(object):
             their greenlets queued up to send.
         """
         found = False
-        for evtype, bucket in self.secondaries.items():
+        for evtype, bucket in six.iteritems(self.secondaries):
             if fileno in bucket:
                 for listener in bucket[fileno]:
                     found = True
@@ -197,7 +198,7 @@ class BaseHub(object):
 
         # For the primary listeners, we actually need to call remove,
         # which may modify the underlying OS polling objects.
-        for evtype, bucket in self.listeners.items():
+        for evtype, bucket in six.iteritems(self.listeners):
             if fileno in bucket:
                 listener = bucket[fileno]
                 found = True
